@@ -546,8 +546,14 @@ VR.Views.Proc = Backbone.View.extend({
 });
 
 
-VR.Views.ProcModal = Backbone.View.extend({
-    el: '<div class="modalwrap" tabindex="-1"></div>',
+VR.Views.BaseModal = Backbone.View.extend({
+    // base class for bootstrap modal views, which need to have tabindex set in
+    // order for them to be dismissable with the Escape key.
+    el: '<div class="modalwrap" tabindex="-1"></div>'
+});
+
+
+VR.Views.ProcModal = VR.Views.BaseModal.extend({
     initialize: function(proc) {
       this.proc = proc;
       this.fresh = true;
@@ -753,13 +759,15 @@ VR.Views.Swarm = Backbone.View.extend({
     render: function() {
       this.$el.html(this.template.goatee(this.swarm.toJSON()));
     },
-    onRemove: function() {
-      this.$el.remove();
+    onRemove: function(model) {
+      // filter out host removal events that have bubbled up from below
+      if (model === this) {
+        this.$el.remove();
+      }
     }
 });
 
-VR.Views.SwarmModal = Backbone.View.extend({
-    el: '<div class="modalwrap" tabindex="-1"></div>',
+VR.Views.SwarmModal = VR.Views.BaseModal.extend({
     initialize: function(swarm, template) {
       this.swarm = swarm;
       this.current_state = '';
@@ -864,8 +872,7 @@ VR.Views.App = Backbone.View.extend({
     },
 
     events: {
-      'click .titlecell .expandtree': 'toggleExpanded',
-      'click .apptitle': 'appModal'
+      'click .apptitle, .titlecell .expandtree': 'toggleExpanded'
     },
 
     toggleExpanded: function() {
@@ -874,39 +881,19 @@ VR.Views.App = Backbone.View.extend({
       this.$el.find('.titlecell > .expandtree > i').toggleClass('icon-caret-right').toggleClass('icon-caret-down');
     },
 
-    appModal: function() {
-      if (!this.modal) {
-        this.modal = new VR.Views.AppModal(this.app);   
-      }
-
-      this.modal.show();
-    },
-
     render: function() {
       this.$el.html(this.template.goatee(this.app.toJSON()));
       var plv = new VR.Views.ProcList(this.app);
       this.$el.find('td').append(plv.el);
     },
 
-    onRemove: function() {
-      this.$el.remove();
-    }
-});
-
-VR.Views.AppModal = Backbone.View.extend({
-    el: '<div class="modalwrap" tabindex="-1"></div>',
-    initialize: function(app, template) {
-      this.app = app;
-      this.template = template || VR.Templates.AppModal;
-    },
-
-    render: function() {
-      this.$el.html(this.template.goatee(this.app.toJSON()));
-    },
-
-    show: function() {
-      this.render();
-      this.$el.modal('show');
+    onRemove: function(model) {
+      console.log('vr.views.app.remove', model);
+      // swarm removal events are bubbled up here as well as app removal
+      // events.  Only remove self if self.app is the thing just removed
+      if (model === this.app) {
+        this.$el.remove();
+      }
     }
 });
 
@@ -945,7 +932,7 @@ VR.Views.Event = Backbone.View.extend({
         this.model = model;
         this.model.on('destroy', this.onDestroy, this);
         this.template = template || VR.Templates.Event;
-        this.modalTemplate = modalTemplate || VR.Templates.EventDetail;
+        this.modalTemplate = modalTemplate || VR.Templates.EventModal;
         this.render();
     },
 
@@ -962,10 +949,10 @@ VR.Views.Event = Backbone.View.extend({
     },
 
     onClick: function(ev) {
-      // When you click an Event, you should see an EventDetail modal.  These
+      // When you click an Event, you should see an EventModal modal.  These
       // are created on the fly when first requested.
       if (!this.modal) {
-        this.modal = new VR.Views.EventDetail(this.model, this.modalTemplate);   
+        this.modal = new VR.Views.EventModal(this.model, this.modalTemplate);   
       }
 
       this.modal.show();
@@ -974,10 +961,10 @@ VR.Views.Event = Backbone.View.extend({
 
 
 // The modal that provides additional details about the event.
-VR.Views.EventDetail = Backbone.View.extend({
+VR.Views.EventModal = VR.Views.BaseModal.extend({
     initialize: function(model, template) {
       this.model = model;
-      this.template = template || VR.Templates.EventDetail;
+      this.template = template || VR.Templates.EventModal;
       this.model.on('change', this.render, this);
       this.model.on('remove', this.onRemove, this);
     },
